@@ -179,7 +179,7 @@ class InterpretCommand(commands.CommandBase):
         self.jit_compiled = True
         self.command_sequence = []
 
-        self.errors = True
+        self.errors = []
 
         self.addRequirements(requirements)
         self.reset()
